# CHANGELOG

## v0.9.0
- Enable support for Python 3.11, 3.12, and 3.13
- Drop support for Python 3.7 and 3.8
- Update flask to version 3.1
- Update flask-sqlalchemy to version 3.1

## v0.8.0
- Update flask-sqlalchemy to version 3

## v0.7.0
- Drop support for Python 3.5 and 3.5
- Enable support for Python 3.9 and 3.10

## v0.6.1
- Allow non-required model fields in Markdown loader

## v0.6.0
- Support Markdown-Frontmatter formatted content

## v0.5.0
- Support Python 3.8

## v0.4.1
- Check for missing models when loading data

## v0.4.0
- Refactor
- Enforce YAML file extensions when loading records from multiple files in a directory

## v0.3.1
- Update package metadata
- Minor cleanups

## v0.3.0
- Use `ruamel.yaml` for proper unicode handling
- Include support for Python 3.4 and 3.7
- Improve documentation

## v0.2.0
- Support reading all rows from `_all.yml` inside the model directory

## v0.1.0
- First release
